﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Text;
using Infragistics.Win.UltraWinEditors;
using System.Text.RegularExpressions;

namespace UltraDateTimeEditorInheriteCustomTimePicker
{
    public partial class UltraTimePicker : UltraComboEditor
    {

        private bool use24Format;
        [Category("Behavior")]
        [Description("Get/Set Time Format (01:00 PM or 13:00)")]
        public bool Use24Format
        {
            get
            {
                return use24Format;
            }
            set
            {
                if (use24Format != value)
                {
                    use24Format = value;
                    SetValues(value, minutesInterval);
                    EventArgs eArg = new EventArgs();
                    if(ChangeFormat != null) ChangeFormat(this, eArg);

                }
            }
        }

        private int minutesInterval;
        [Category("Behavior")]
        [Description("Get/Set Interval between items in dropdown list")]
        public int MinutesInterval
        {
            get
            {
                return minutesInterval;
            }
            set
            {
                if (value == 0) value = 15;
                minutesInterval = value;
                SetValues(use24Format, value);

            }
        }

        public delegate void ChangingHandler(object sender, EventArgs eArg);
        [Category("Property Changed")]
        [Description("The event fired when Use24Format property is change")]
        public event ChangingHandler ChangeFormat;

        public UltraTimePicker()
        {
            InitializeComponent();
        }

        public UltraTimePicker(IContainer container)
        {
            container.Add(this);
            InitializeComponent();
            this.KeyPress += new System.Windows.Forms.KeyPressEventHandler(UltraTimePicker_KeyPress);
        }

        void UltraTimePicker_KeyPress(object sender, System.Windows.Forms.KeyPressEventArgs e)
        {
            if (e.KeyChar != '\b' && e.KeyChar != ':')
            {
                Regex regStr = new Regex(@"([0-9])");
                if (!regStr.IsMatch(e.KeyChar.ToString())) e.Handled = true;
            }
        }

        private void SetValues(bool Format, int interval)
        {
            this.ValueList.ValueListItems.Clear();
            for (int i = 0; i < 1440; i++)
            {
                if (use24Format)
                {
                    this.ValueList.ValueListItems.Add(i, String.Format("{0:T}", DateTime.Today.AddMinutes(i)));
                }
                else
                {
                    if (i > 719) this.ValueList.ValueListItems.Add(i, String.Format("{0:h:mm} PM", DateTime.Today.AddMinutes(i)));
                    else this.ValueList.ValueListItems.Add(i, String.Format("{0:h:mm} AM", DateTime.Today.AddMinutes(i)));
                }
                i += interval - 1;
            }
        }
    }
}
